@@ -6,7 +6,7 @@ use warnings;
 
 use Data::Dumper;
 
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 
 # overload these operators to have special meaning when
 # operand(s) are Statistics::Running:
@@ -563,7 +563,7 @@ Statistics::Running - Basic descriptive statistics (mean/stdev/min/max/skew/kurt
 
 =head1 VERSION
 
-Version 0.1
+Version 0.11
 
 
 =head1 SYNOPSIS
@@ -785,6 +785,21 @@ to this sub.
 Enables histogram logging by creating a histogram with specified
 parameters. These parameters can be of different formats:
 
+	my $ru1 = Statistics::Running->new();
+	$ru1->histogram_enable({
+		'num-bins' => 10,
+		'bin-width' => 0.01,
+		'left-boundary' => 0
+	});
+	# or, 2 bins: 0-1 and 1-2
+	$ru1->histogram_enable({
+		'0:1' => 0,
+		'1:2' => 1,
+	});
+	# or, 2 bins: 0-1 and 1-2
+	$ru1->histogram_enable([0,1,2]);
+
+
 =over 3
 
 =item 1. by specifying the number of bins, bin-width and left boundary as a
